Method: Natsy::Config::Options#urls
- Defined in:
- lib/natsy/config.rb
#urls ⇒ Object
Specify a NATS server URL (or multiple URLs)
NOTE: The following two examples do exactly the same thing.
NOTE: The following two examples do exactly the same thing.
If left blank/omitted, natsy will fall back on the default URL, which is nats://localhost:4222.
43 44 45 |
# File 'lib/natsy/config.rb', line 43 def urls @urls end |